@@ -66,6 +66,7 @@ def cli():
 
 
 @click.command()
+@click.option('--verbose/--no-verbose', **OPTION_ARGS_DEFAULT_FALSE)
 def mypy(verbose: bool = True):
     """Run Mypy (configured in pyproject.toml)"""
     verbose_check_call('mypy', '.', cwd=PACKAGE_ROOT, verbose=verbose, exit_on_error=True)
@@ -75,12 +76,15 @@ cli.add_command(mypy)
 
 
 @click.command()
+@click.option('--verbose/--no-verbose', **OPTION_ARGS_DEFAULT_FALSE)
 def coverage(verbose: bool = True):
     """
     Run and show coverage.
     """
     verbose_check_call('coverage', 'run', verbose=verbose, exit_on_error=True)
+    verbose_check_call('coverage', 'combine', '--append', verbose=verbose, exit_on_error=True)
     verbose_check_call('coverage', 'report', '--fail-under=50', verbose=verbose, exit_on_error=True)
+    verbose_check_call('coverage', 'xml', verbose=verbose, exit_on_error=True)
     verbose_check_call('coverage', 'json', verbose=verbose, exit_on_error=True)
 
 
@@ -115,15 +119,17 @@ def update():
     """
     Update "requirements*.txt" dependencies files
     """
-    verbose_check_call('pip', 'install', '-U', 'pip')
-    verbose_check_call('pip', 'install', '-U', 'pip-tools')
+    bin_path = Path(sys.executable).parent
+
+    verbose_check_call(bin_path / 'pip', 'install', '-U', 'pip')
+    verbose_check_call(bin_path / 'pip', 'install', '-U', 'pip-tools')
 
     extra_env = dict(
         CUSTOM_COMPILE_COMMAND='./cli.py update',
     )
 
     pip_compile_base = [
-        'pip-compile',
+        bin_path / 'pip-compile',
         '--verbose',
         '--allow-unsafe',  # https://pip-tools.readthedocs.io/en/latest/#deprecations
         '--resolver=backtracking',  # https://pip-tools.readthedocs.io/en/latest/#deprecations
@@ -140,7 +146,7 @@ def update():
         extra_env=extra_env,
     )
 
-    # dependencies + "tests"-optional-dependencies:
+    # dependencies + "dev"-optional-dependencies:
     verbose_check_call(
         *pip_compile_base,
         'pyproject.toml',
